@@ -18,6 +18,7 @@
 
 from __future__ import annotations
 
+from os import getenv
 from typing import TYPE_CHECKING
 
 from gitlab import Gitlab
@@ -54,7 +55,15 @@ class PyGitlab(object):
         self._gitlab_id = gitlab_id
         self._config_files = config_files
         self._debug = debug
-        self._gl = Gitlab.from_config(self.gitlab_id, self._config_files)
+        try:
+            options = {
+                'server_url': getenv('GITLAB_URL'),
+                'private_token': getenv('GITLAB_PRIVATE_TOKEN'),
+                'oauth_token': getenv('GITLAB_OAUTH_TOKEN'),
+            }
+            self._gl = Gitlab.merge_config(options, self.gitlab_id, self._config_files)
+        except AttributeError:
+            self._gl = Gitlab.from_config(self.gitlab_id, self._config_files)
         if auth:
             if self.pygitlab.private_token or self.pygitlab.oauth_token:
                 self.pygitlab.auth()
