@@ -115,12 +115,11 @@ class Github(Source):
                     latest_release = self._repo.get_latest_release()
                     self._matching_releases[latest_release.tag_name] = latest_release
                 except UnknownObjectException as err2:
-                    logger.warning(
-                        '%sError getting package files from repository %s, latest release: %s %s',
+                    logger.warning(  # noqa: G200
+                        '%sError getting package files from repository %s, latest release: %s',
                         self._log_prefix,
                         self._full_name,
-                        err2.status,
-                        err2.data.get('message'),
+                        str(err2),
                     )
         return self._matching_releases
 
@@ -139,13 +138,12 @@ class Github(Source):
             try:
                 self._matching_releases[tag_name] = self._repo.get_release(tag_name)  # type: ignore
             except UnknownObjectException as err:
-                logger.warning(
-                    '%sError getting package files from repository %s, release with tag %s: %s %s',
+                logger.warning(  # noqa: G200
+                    '%sError getting package files from repository %s, release with tag %s: %s',
                     self._log_prefix,
                     self._full_name,
                     tag_name,
-                    err.status,
-                    err.data.get('message'),
+                    str(err),
                 )
         else:
             self._matching_releases[tag_name] = self._all_releases[tag_name]  # type: ignore
